pub struct StopOrder {
pub stop_id: StopId,
pub scope_type: StopScopeType,
pub scope_id: String,
pub reason_code: String,
pub reason_text: String,
pub issued_at: OffsetDateTime,
}Expand description
An order to stop a project or task tree.
Fields
stop_id: StopIdUnique stop order identifier.
scope_type: StopScopeTypeWhether this stops a project or a task tree.
scope_id: StringID of the entity being stopped.
reason_code: StringMachine-readable reason code.
reason_text: StringHuman-readable reason text.
issued_at: OffsetDateTimeWhen the stop order was issued.