pub trait RoutedBody {
// Required method
fn msg_type(&self) -> MsgType;
}Expand description
Trait implemented by all message body types to declare their MsgType.
pub trait RoutedBody {
// Required method
fn msg_type(&self) -> MsgType;
}Trait implemented by all message body types to declare their MsgType.